#include <Pilot.h>
#include "PTestRsc.h"
#include "SoundMgr.h"

/***************************************************************
 * Global variables for this module
 ***************************************************************/

static MenuBarPtr	CurrentMenu = NULL; // Pointer to current menu
static Word			CurrentView;

/***************************************************************
 * Prototypes for internal functions
 ***************************************************************/

static void		StartApplication (void);
static void 	SetCurrentMenu(Word rscID);	// set new current menu
static Boolean	EditFormHandleEvent (EventPtr event);
static Boolean	MainFormHandleEvent (EventPtr event);
static Boolean	ApplicationHandleEvent (EventPtr event);
static void		EventLoop (void);

/***************************************************************
 * StartApplication
 ***************************************************************/

static void StartApplication (void)
{
	CurrentView=mainForm;
	FrmGotoForm(CurrentView);
	
	SetCurrentMenu(MainFormMenuBar); // set the current menu
}

/***********************************************************************
 *
 * FUNCTION:    SetCurrentMenu
 *
 * DESCRIPTION: This routine loads the specified menu resource and makes
 *              it the current menu.  
 *
 * PARAMETERS:  rscID  - resource id of the new menu
 *
 * RETURNED:    nothing
 *
 ***********************************************************************/
static void SetCurrentMenu(Word rscID)
{
	// Dispose of an existing current menu.
	if (CurrentMenu)
		MenuDispose(CurrentMenu);
	
	// Set the current menu and remember it.
	CurrentMenu = MenuInit(rscID);
}


/***************************************************************
 * MainFormHandleEvent
 ***************************************************************/
 
static Boolean MainFormHandleEvent (EventPtr event)
{
	Boolean		handled=false;
	// EventType	newEvent;
	FormPtr		frm;
	
	switch (event->eType)
	{
	
	/* check for a control event like a button tap */
	
		case ctlSelectEvent:
		/*	if (event->data.ctlEnter.controlID==mainExitButton)
		//	|| (event->data.ctlEnter.controlID==PilotTestInfoOKButton)
			{
				MemSet (&newEvent, sizeof(EventType), 0);
				newEvent.eType = appStopEvent;
				EvtAddEventToQueue (&newEvent);
				handled=true;
			} */
			
			break;
			
	/* check for a form open event */
	
		case frmOpenEvent:
			FrmDrawForm(FrmGetActiveForm());
			handled=true;
			break;
			
		case menuEvent:	// process menu events for this form
		{
		// A menu item was selected.
		// The get info being the only menu item, display the info form.
		
		// First clear the menu status from the display.
		MenuEraseStatus(CurrentMenu);
		
		// Beep!
		
		SndPlaySystemSound(sndWarning);
		
		// Load the info form, then display it.
		frm = FrmInitForm(PilotTestInfoForm);
		FrmDoDialog(frm);
		
		// Delete the info form.
 		FrmDeleteForm(frm);
		handled = true;
		}
			
	}
	
	return (handled);
}

/***************************************************************
 * ApplicationHandleEvent
 ***************************************************************/
 
static Boolean ApplicationHandleEvent (EventPtr event)
{
	FormPtr	frm;
	Word	formId;
	Boolean	handled=false;
	
	/* check for a form load event */
	
	if (event->eType==frmLoadEvent)
	{
		formId=event->data.frmLoad.formID;
		frm=FrmInitForm(formId);
		FrmSetActiveForm(frm);
		
		/* if so, load the appropriate form event handler */
		
		switch (formId)
		{
			case mainForm:
				FrmSetEventHandler(frm, MainFormHandleEvent);
				break;
		}
		
		handled=true;
	}
	
	return handled;
}

/***************************************************************
 * EventLoop
 ***************************************************************/
 
static void EventLoop (void)
{
	EventType 	event;
	Word		error;
	
	do
	{
		EvtGetEvent(&event, evtWaitForever);
		
		if (!SysHandleEvent(&event))
		// Give the menu bar a chance to update and handle the event.	
			if (!MenuHandleEvent(CurrentMenu, &event, &error))
				if (!ApplicationHandleEvent(&event))
					FrmDispatchEvent(&event);
	}	
	
	while (event.eType != appStopEvent);
}


/***************************************************************
 * PilotMain
 ***************************************************************/
 
DWord PilotMain(Word cmd, Ptr cmdPBP, Word launchFlags)
{
	if (cmd==sysAppLaunchCmdNormalLaunch) // Deal with sysAppLaunchCmdSystemReset properly
										  // Prevents Fatal Error at HotSync and crashing at start-up	
	{
		StartApplication();
		EventLoop();
	}
	
	return 0;
}	
